@@ -3,10 +3,11 @@ import logging
 from os.path import join
 from typing import Any, Dict, List, Optional, Union
 
-from hdx.data.hdxobject import HDXError, HDXObject
-from hdx.hdx_configuration import Configuration
 from hdx.utilities.uuid import is_valid_uuid
 
+from hdx.api.configuration import Configuration
+from hdx.data.hdxobject import HDXError, HDXObject
+
 logger = logging.getLogger(__name__)
 
 
@@ -82,7 +83,9 @@ class ResourceView(HDXObject):
         Returns:
             Optional[ResourceView]: ResourceView object if successful read, None if not
         """
-        return cls._read_from_hdx_class("resource view", identifier, configuration)
+        return cls._read_from_hdx_class(
+            "resource view", identifier, configuration
+        )
 
     @staticmethod
     def get_all_for_resource(
@@ -130,11 +133,15 @@ class ResourceView(HDXObject):
             bool: True if updated and False if not
         """
         update = False
-        if "id" in self.data and self._load_from_hdx("resource view", self.data["id"]):
+        if "id" in self.data and self._load_from_hdx(
+            "resource view", self.data["id"]
+        ):
             update = True
         else:
             if "resource_id" in self.data:
-                resource_views = self.get_all_for_resource(self.data["resource_id"])
+                resource_views = self.get_all_for_resource(
+                    self.data["resource_id"]
+                )
                 for resource_view in resource_views:
                     if self.data["title"] == resource_view["title"]:
                         self.old_data = self.data
@@ -143,7 +150,9 @@ class ResourceView(HDXObject):
                         break
         if update:
             if log:
-                logger.warning(f"resource view exists. Updating {self.data['id']}")
+                logger.warning(
+                    f"resource view exists. Updating {self.data['id']}"
+                )
             self._merge_hdx_update("resource view", "id", **kwargs)
         return update
 
@@ -186,7 +195,9 @@ class ResourceView(HDXObject):
         """
         if isinstance(resource_view, str):
             if is_valid_uuid(resource_view) is False:
-                raise HDXError(f"{resource_view} is not a valid resource view id!")
+                raise HDXError(
+                    f"{resource_view} is not a valid resource view id!"
+                )
             resource_view = ResourceView.read_from_hdx(resource_view)
         if not isinstance(resource_view, dict) and not isinstance(
             resource_view, ResourceView
