@@ -7,15 +7,15 @@ from os import remove
 from os.path import join
 
 import pytest
+from hdx.utilities.dictandlist import merge_two_dictionaries
+from hdx.utilities.loader import load_yaml
 
+from hdx.api import __version__
+from hdx.api.configuration import Configuration
 from hdx.data.dataset import Dataset, NotRequestableError
 from hdx.data.hdxobject import HDXError
 from hdx.data.resource import Resource
 from hdx.data.resource_view import ResourceView
-from hdx.hdx_configuration import Configuration
-from hdx.utilities.dictandlist import merge_two_dictionaries
-from hdx.utilities.loader import load_yaml
-from hdx.version import get_api_version
 
 from . import (
     MockResponse,
@@ -140,7 +140,9 @@ def mockall(url, datadict):
         if datadict["start"] == 2:
             newsearchdict["results"] = newsearchdict["results"][2:9]
         else:
-            newsearchdict["results"] = newsearchdict["results"][4:5]  # repeated dataset
+            newsearchdict["results"] = newsearchdict["results"][
+                4:5
+            ]  # repeated dataset
     elif datadict["rows"] == 5:
         newsearchdict["count"] = 6
         if datadict["sort"] == "metadata_modified desc":
@@ -213,7 +215,8 @@ class TestDatasetCore:
             def post(url, data, headers, files, allow_redirects, auth=None):
                 if isinstance(data, dict):
                     datadict = {
-                        k.decode("utf8"): v.decode("utf8") for k, v in data.items()
+                        k.decode("utf8"): v.decode("utf8")
+                        for k, v in data.items()
                     }
                 else:
                     datadict = json.loads(data.decode("utf-8"))
@@ -241,7 +244,8 @@ class TestDatasetCore:
             def post(url, data, headers, files, allow_redirects, auth=None):
                 if isinstance(data, dict):
                     datadict = {
-                        k.decode("utf8"): v.decode("utf8") for k, v in data.items()
+                        k.decode("utf8"): v.decode("utf8")
+                        for k, v in data.items()
                     }
                 else:
                     datadict = json.loads(data.decode("utf-8"))
@@ -314,7 +318,8 @@ class TestDatasetCore:
             def post(url, data, headers, files, allow_redirects, auth=None):
                 if isinstance(data, dict):
                     datadict = {
-                        k.decode("utf8"): v.decode("utf8") for k, v in data.items()
+                        k.decode("utf8"): v.decode("utf8")
+                        for k, v in data.items()
                     }
                 else:
                     datadict = json.loads(data.decode("utf-8"))
@@ -362,8 +367,12 @@ class TestDatasetCore:
                     if datadict["name"] in ["MyDataset1", "DatasetExist"]:
                         resultdictcopy = copy.deepcopy(dataset_resultdict)
                         merge_two_dictionaries(resultdictcopy, datadict)
-                        for i, resource in enumerate(resultdictcopy["resources"]):
-                            for j, resource2 in enumerate(resultdictcopy["resources"]):
+                        for i, resource in enumerate(
+                            resultdictcopy["resources"]
+                        ):
+                            for j, resource2 in enumerate(
+                                resultdictcopy["resources"]
+                            ):
                                 if i != j:
                                     if resource == resource2:
                                         del resultdictcopy["resources"][j]
@@ -554,6 +563,15 @@ class TestDatasetCore:
         dataset = Dataset(datasetdata)
         resourcesdata = copy.deepcopy(resources_data)
         resource = Resource(resourcesdata[0])
+        del resource["description"]
+        del dataset["tags"]
+        dataset.add_update_resources([resource, resource])
+        with pytest.raises(HDXError):
+            dataset.create_in_hdx()
+        dataset.create_in_hdx(ignore_fields=["tags", "resource:description"])
+        dataset = Dataset(datasetdata)
+        resourcesdata = copy.deepcopy(resources_data)
+        resource = Resource(resourcesdata[0])
         dataset.add_update_resources([resource, resource])
         dataset.create_in_hdx()
         assert dataset["id"] == "6f36a41c-f126-4b18-aaaf-6c2ddfbc5d4d"
@@ -579,7 +597,7 @@ class TestDatasetCore:
         dataset.create_in_hdx(ignore_check=True)
 
         config = Configuration(user_agent="test", hdx_read_only=True)
-        config.setup_remoteckan()
+        config.setup_session_remoteckan()
         config.remoteckan().session = Configuration.read().remoteckan().session
         uniqueval = "myconfig"
         config.unique = uniqueval
@@ -635,7 +653,7 @@ class TestDatasetCore:
         assert dataset["state"] == "active"
         pattern = (
             r"HDXPythonLibrary/%s-test \([12]\d\d\d-\d\d-\d\dT\d\d:\d\d:\d\d.\d\d\d\d\d\d\)"
-            % get_api_version()
+            % __version__
         )
         match = re.search(pattern, dataset["updated_by_script"])
         assert match
@@ -652,7 +670,8 @@ class TestDatasetCore:
         match = re.search(pattern, dataset["updated_by_script"])
         assert match
         dataset.update_in_hdx(
-            updated_by_script="hi", batch="6f36a41c-f126-4b18-aaaf-6c2ddfbc5d4d"
+            updated_by_script="hi",
+            batch="6f36a41c-f126-4b18-aaaf-6c2ddfbc5d4d",
         )
         match = re.search(pattern, dataset["updated_by_script"])
         assert match
@@ -791,6 +810,25 @@ class TestDatasetCore:
         assert dataset["state"] == "active"
         assert len(dataset.resources) == 1
 
+        dataset = Dataset.read_from_hdx("TEST1")
+        resources = dataset.get_resources()
+        resource_ids = [x["id"] for x in resources]
+        assert resource_ids == [
+            "de6549d8-268b-4dfe-adaf-a4ae5c8510d5",
+            "3d777226-96aa-4239-860a-703389d16d1f",
+            "3d777226-96aa-4239-860a-703389d16d1g",
+        ]
+        dataset["id"] = "TEST1"
+        dataset["name"] = "MyDataset1"
+        dataset.resources = [resources[2], resources[0], resources[1]]
+        dataset.update_in_hdx(match_resource_order=True)
+        resource_ids = [x["id"] for x in dataset.get_resources()]
+        assert resource_ids == [
+            "3d777226-96aa-4239-860a-703389d16d1g",
+            "de6549d8-268b-4dfe-adaf-a4ae5c8510d5",
+            "3d777226-96aa-4239-860a-703389d16d1f",
+        ]
+
     def test_delete_from_hdx(self, configuration, post_delete):
         dataset = Dataset.read_from_hdx("TEST1")
         dataset.delete_from_hdx()
@@ -956,18 +994,32 @@ class TestDatasetCore:
 
     def test_reorder_resources(self, configuration, post_reorder):
         dataset = Dataset.read_from_hdx("TEST1")
+        resource_ids = [x["id"] for x in dataset.get_resources()]
+        assert resource_ids == [
+            "de6549d8-268b-4dfe-adaf-a4ae5c8510d5",
+            "3d777226-96aa-4239-860a-703389d16d1f",
+            "3d777226-96aa-4239-860a-703389d16d1g",
+        ]
         dataset.reorder_resources(
             [
                 "3d777226-96aa-4239-860a-703389d16d1f",
                 "de6549d8-268b-4dfe-adaf-a4ae5c8510d5",
+                "3d777226-96aa-4239-860a-703389d16d1g",
             ]
         )
+        resource_ids = [x["id"] for x in dataset.get_resources()]
+        assert resource_ids == [
+            "3d777226-96aa-4239-860a-703389d16d1f",
+            "de6549d8-268b-4dfe-adaf-a4ae5c8510d5",
+            "3d777226-96aa-4239-860a-703389d16d1g",
+        ]
         del dataset["id"]
         with pytest.raises(HDXError):
             dataset.reorder_resources(
                 [
                     "3d777226-96aa-4239-860a-703389d16d1f",
                     "de6549d8-268b-4dfe-adaf-a4ae5c8510d5",
+                    "3d777226-96aa-4239-860a-703389d16d1g",
                 ]
             )
 
